@@ -1,7 +1,7 @@
 /*
  * libbrlapi - A library providing access to braille terminals for applications.
  *
- * Copyright (C) 2002-2020 by
+ * Copyright (C) 2002-2025 by
  *   Samuel Thibault <Samuel.Thibault@ens-lyon.org>
  *   Sébastien Hinderer <Sebastien.Hinderer@ens-lyon.org>
  *
@@ -176,7 +176,7 @@ extern "C" {
 #define BRLAPI_KEY_CMD_SWITCHVT_NEXT (BRLAPI_KEY_CMD(0) + 71)
 /** bring screen cursor to current line */
 #define BRLAPI_KEY_CMD_CSRJMP_VERT (BRLAPI_KEY_CMD(0) + 72)
-/** insert clipboard text after screen cursor */
+/** insert the clipboard content before the screen cursor */
 #define BRLAPI_KEY_CMD_PASTE (BRLAPI_KEY_CMD(0) + 73)
 /** restart braille driver */
 #define BRLAPI_KEY_CMD_RESTARTBRL (BRLAPI_KEY_CMD(0) + 74)
@@ -286,6 +286,68 @@ extern "C" {
 #define BRLAPI_KEY_CMD_ASPK_INDENT (BRLAPI_KEY_CMD(0) + 126)
 /** refresh braille display */
 #define BRLAPI_KEY_CMD_REFRESH (BRLAPI_KEY_CMD(0) + 127)
+/** show various device status indicators */
+#define BRLAPI_KEY_CMD_INDICATORS (BRLAPI_KEY_CMD(0) + 128)
+/** clear the text selection */
+#define BRLAPI_KEY_CMD_TXTSEL_CLEAR (BRLAPI_KEY_CMD(0) + 129)
+/** select all of the text */
+#define BRLAPI_KEY_CMD_TXTSEL_ALL (BRLAPI_KEY_CMD(0) + 130)
+/** copy selected text to host clipboard */
+#define BRLAPI_KEY_CMD_HOST_COPY (BRLAPI_KEY_CMD(0) + 131)
+/** cut selected text to host clipboard */
+#define BRLAPI_KEY_CMD_HOST_CUT (BRLAPI_KEY_CMD(0) + 132)
+/** insert the host clipboard text before the screen cursor */
+#define BRLAPI_KEY_CMD_HOST_PASTE (BRLAPI_KEY_CMD(0) + 133)
+/** show the window title */
+#define BRLAPI_KEY_CMD_GUI_TITLE (BRLAPI_KEY_CMD(0) + 134)
+/** open the braille actions window */
+#define BRLAPI_KEY_CMD_GUI_BRL_ACTIONS (BRLAPI_KEY_CMD(0) + 135)
+/** go to the home screen */
+#define BRLAPI_KEY_CMD_GUI_HOME (BRLAPI_KEY_CMD(0) + 136)
+/** go back to the previous screen */
+#define BRLAPI_KEY_CMD_GUI_BACK (BRLAPI_KEY_CMD(0) + 137)
+/** open the device settings window */
+#define BRLAPI_KEY_CMD_GUI_DEV_SETTINGS (BRLAPI_KEY_CMD(0) + 138)
+/** open the device options window */
+#define BRLAPI_KEY_CMD_GUI_DEV_OPTIONS (BRLAPI_KEY_CMD(0) + 139)
+/** open the application list window */
+#define BRLAPI_KEY_CMD_GUI_APP_LIST (BRLAPI_KEY_CMD(0) + 140)
+/** open the application-specific menu */
+#define BRLAPI_KEY_CMD_GUI_APP_MENU (BRLAPI_KEY_CMD(0) + 141)
+/** open the application alerts window */
+#define BRLAPI_KEY_CMD_GUI_APP_ALERTS (BRLAPI_KEY_CMD(0) + 142)
+/** return to the active screen area */
+#define BRLAPI_KEY_CMD_GUI_AREA_ACTV (BRLAPI_KEY_CMD(0) + 143)
+/** switch to the previous screen area */
+#define BRLAPI_KEY_CMD_GUI_AREA_PREV (BRLAPI_KEY_CMD(0) + 144)
+/** switch to the next screen area */
+#define BRLAPI_KEY_CMD_GUI_AREA_NEXT (BRLAPI_KEY_CMD(0) + 145)
+/** move to the first item in the screen area */
+#define BRLAPI_KEY_CMD_GUI_ITEM_FRST (BRLAPI_KEY_CMD(0) + 146)
+/** move to the previous item in the screen area */
+#define BRLAPI_KEY_CMD_GUI_ITEM_PREV (BRLAPI_KEY_CMD(0) + 147)
+/** move to the next item in the screen area */
+#define BRLAPI_KEY_CMD_GUI_ITEM_NEXT (BRLAPI_KEY_CMD(0) + 148)
+/** move to the last item in the screen area */
+#define BRLAPI_KEY_CMD_GUI_ITEM_LAST (BRLAPI_KEY_CMD(0) + 149)
+/** decrease speaking pitch */
+#define BRLAPI_KEY_CMD_SAY_LOWER (BRLAPI_KEY_CMD(0) + 150)
+/** increase speaking pitch */
+#define BRLAPI_KEY_CMD_SAY_HIGHER (BRLAPI_KEY_CMD(0) + 151)
+/** speak from top of screen through bottom of screen */
+#define BRLAPI_KEY_CMD_SAY_ALL (BRLAPI_KEY_CMD(0) + 152)
+/** set contracted/computer braille */
+#define BRLAPI_KEY_CMD_CONTRACTED (BRLAPI_KEY_CMD(0) + 153)
+/** set six/eight dot computer braille */
+#define BRLAPI_KEY_CMD_COMPBRL6 (BRLAPI_KEY_CMD(0) + 154)
+/** reset preferences to defaults */
+#define BRLAPI_KEY_CMD_PREFRESET (BRLAPI_KEY_CMD(0) + 155)
+/** set autospeak empty line on/off */
+#define BRLAPI_KEY_CMD_ASPK_EMP_LINE (BRLAPI_KEY_CMD(0) + 156)
+/** cycle speech punctuation level */
+#define BRLAPI_KEY_CMD_SPK_PUNCT_LEVEL (BRLAPI_KEY_CMD(0) + 157)
+/** insert the clipboard content before the screen cursor using the alternate paste mode */
+#define BRLAPI_KEY_CMD_PASTE_ALTMODE (BRLAPI_KEY_CMD(0) + 158)
 /** bring screen cursor to character */
 #define BRLAPI_KEY_CMD_ROUTE BRLAPI_KEY_CMD(1)
 /** start new clipboard at character */
@@ -332,7 +394,7 @@ extern "C" {
 #define BRLAPI_KEY_CMD_CLIP_APPEND BRLAPI_KEY_CMD(17)
 /** deprecated definition of CLIP_APPEND - append characters to clipboard */
 #define BRLAPI_KEY_CMD_APNDCHARS BRLAPI_KEY_CMD(17)
-/** insert clipboard history entry after screen cursor */
+/** insert a clipboard history entry before the screen cursor */
 #define BRLAPI_KEY_CMD_PASTE_HISTORY BRLAPI_KEY_CMD(18)
 /** set text table */
 #define BRLAPI_KEY_CMD_SET_TEXT_TABLE BRLAPI_KEY_CMD(19)
@@ -348,6 +410,14 @@ extern "C" {
 #define BRLAPI_KEY_CMD_ROUTE_LINE BRLAPI_KEY_CMD(24)
 /** refresh braille line */
 #define BRLAPI_KEY_CMD_REFRESH_LINE BRLAPI_KEY_CMD(25)
+/** start text selection */
+#define BRLAPI_KEY_CMD_TXTSEL_START BRLAPI_KEY_CMD(26)
+/** set text selection */
+#define BRLAPI_KEY_CMD_TXTSEL_SET BRLAPI_KEY_CMD(27)
+/** bring speech cursor to character */
+#define BRLAPI_KEY_CMD_ROUTE_SPEECH BRLAPI_KEY_CMD(28)
+/** insert a clipboard history entry before the screen cursor using the alternate paste mode */
+#define BRLAPI_KEY_CMD_PASTE_HISTORY_ALTMODE BRLAPI_KEY_CMD(29)
 /** bind to specific virtual terminal */
 #define BRLAPI_KEY_CMD_SELECTVT BRLAPI_KEY_CMD(30)
 /** render an alert */
@@ -364,6 +434,10 @@ extern "C" {
 #define BRLAPI_KEY_CMD_CONTEXT BRLAPI_KEY_CMD(38)
 /** current reading location */
 #define BRLAPI_KEY_CMD_TOUCH_AT BRLAPI_KEY_CMD(39)
+/** execute command macro */
+#define BRLAPI_KEY_CMD_MACRO BRLAPI_KEY_CMD(40)
+/** run host command */
+#define BRLAPI_KEY_CMD_HOSTCMD BRLAPI_KEY_CMD(41)
 /** enable feature */
 #define BRLAPI_KEY_FLG_TOGGLE_ON BRLAPI_KEY_FLG(0X0100)
 /** disable feature */
@@ -388,6 +462,10 @@ extern "C" {
 #define BRLAPI_KEY_FLG_ALTGR BRLAPI_KEY_FLG(0X10)
 /** gui (windows) key pressed */
 #define BRLAPI_KEY_FLG_GUI BRLAPI_KEY_FLG(0X20)
+/** prefix with escape */
+#define BRLAPI_KEY_FLG_ESCAPED BRLAPI_KEY_FLG(0X40)
+/** capslock key pressed */
+#define BRLAPI_KEY_FLG_CAPSLOCK BRLAPI_KEY_FLG(0X80)
 /** it is a release scan code */
 #define BRLAPI_KEY_FLG_KBD_RELEASE BRLAPI_KEY_FLG(0X0100)
 /** it is an emulation 0 scan code */
